@@ -288,6 +288,24 @@ class TestAwsS3Hook:
 
         assert sorted(dirs) == sorted(hook.list_prefixes(s3_bucket, delimiter="/", page_size=1))
 
+    def test_list_prefixes_when_requester_pays(self, s3_bucket):
+        hook = S3Hook(requester_pays=True)
+        hook.get_conn = MagicMock()
+        hook.get_conn.return_value.get_paginator.return_value.paginate.return_value = []
+
+        assert hook.list_prefixes(s3_bucket, prefix="non-existent/") == []
+
+        hook.get_conn.return_value.get_paginator.return_value.paginate.assert_called_with(
+            Bucket="airflow-test-s3-bucket",
+            Delimiter="",
+            PaginationConfig={
+                "MaxItems": None,
+                "PageSize": None,
+            },
+            Prefix="non-existent/",
+            RequestPayer="requester",
+        )
+
     def test_list_keys(self, s3_bucket):
         hook = S3Hook()
         bucket = hook.get_bucket(s3_bucket)
@@ -325,6 +343,25 @@ class TestAwsS3Hook:
         assert hook.list_keys(s3_bucket, prefix="b*") == []
         assert hook.list_keys(s3_bucket, prefix="b*", apply_wildcard=True) == ["ba", "bxa", "bxb"]
 
+    def test_list_keys_when_requester_pays(self, s3_bucket):
+        hook = S3Hook(requester_pays=True)
+        hook.get_conn = MagicMock()
+        hook.get_conn.return_value.get_paginator.return_value.paginate.return_value = []
+
+        assert hook.list_keys(s3_bucket, prefix="non-existent/") == []
+
+        hook.get_conn.return_value.get_paginator.return_value.paginate.assert_called_with(
+            Bucket="airflow-test-s3-bucket",
+            Delimiter="",
+            PaginationConfig={
+                "MaxItems": None,
+                "PageSize": None,
+            },
+            Prefix="non-existent/",
+            RequestPayer="requester",
+            StartAfter="",
+        )
+
     def test_list_keys_paged(self, s3_bucket):
         hook = S3Hook()
         bucket = hook.get_bucket(s3_bucket)
@@ -345,6 +382,23 @@ class TestAwsS3Hook:
         assert len(hook.get_file_metadata("test", s3_bucket)) == 1
         assert len(hook.get_file_metadata("a", s3_bucket)) == 0
 
+    def test_get_file_metadata_when_requester_pays(self, s3_bucket):
+        hook = S3Hook(requester_pays=True)
+        hook.get_conn = MagicMock()
+        hook.get_conn.return_value.get_paginator.return_value.paginate.return_value = []
+
+        assert hook.get_file_metadata("test", s3_bucket) == []
+
+        hook.get_conn.return_value.get_paginator.return_value.paginate.assert_called_with(
+            Bucket="airflow-test-s3-bucket",
+            PaginationConfig={
+                "MaxItems": None,
+                "PageSize": None,
+            },
+            Prefix="test",
+            RequestPayer="requester",
+        )
+
     def test_head_object(self, s3_bucket):
         hook = S3Hook()
         bucket = hook.get_bucket(s3_bucket)
@@ -355,6 +409,19 @@ class TestAwsS3Hook:
         assert hook.head_object("b", s3_bucket) is None
         assert hook.head_object(f"s3://{s3_bucket}//b") is None
 
+    def test_head_object_when_requester_pays(self, s3_bucket):
+        hook = S3Hook(requester_pays=True)
+        hook.get_conn = MagicMock()
+        hook.get_conn.return_value.head_object.return_value = []
+
+        assert hook.head_object("a", s3_bucket) == []
+
+        hook.get_conn.return_value.head_object.assert_called_with(
+            Bucket="airflow-test-s3-bucket",
+            Key="a",
+            RequestPayer="requester",
+        )
+
     def test_check_for_key(self, s3_bucket):
         hook = S3Hook()
         bucket = hook.get_bucket(s3_bucket)
@@ -373,6 +440,16 @@ class TestAwsS3Hook:
         assert hook.get_key("a", s3_bucket).key == "a"
         assert hook.get_key(f"s3://{s3_bucket}/a").key == "a"
 
+    def test_get_key_when_requester_pays(self, s3_bucket):
+        hook = S3Hook(requester_pays=True)
+        hook.resource = MagicMock()
+
+        hook.get_key("a", s3_bucket)
+
+        hook.resource.Object.return_value.load.assert_called_with(
+            RequestPayer="requester",
+        )
+
     def test_read_key(self, s3_bucket):
         hook = S3Hook()
         bucket = hook.get_bucket(s3_bucket)
@@ -386,8 +463,17 @@ class TestAwsS3Hook:
         mock_get_client_type.return_value.select_object_content.return_value = {
             "Payload": [{"Records": {"Payload": b"Cont\xc3"}}, {"Records": {"Payload": b"\xa9nt"}}]
         }
-        hook = S3Hook()
+        hook = S3Hook(requester_pays=True)
         assert hook.select_key("my_key", s3_bucket) == "Contént"
+        mock_get_client_type.return_value.select_object_content.assert_called_with(
+            Bucket="airflow-test-s3-bucket",
+            Expression="SELECT * FROM S3Object",
+            ExpressionType="SQL",
+            ExtraArgs={"RequestPayer": "requester"},
+            InputSerialization={"CSV": {}},
+            Key="my_key",
+            OutputSerialization={"CSV": {}},
+        )
 
     def test_check_for_wildcard_key(self, s3_bucket):
         hook = S3Hook()
@@ -473,7 +559,11 @@ class TestAwsS3Hook:
         assert response["Grants"][0]["Permission"] == "FULL_CONTROL"
 
     @pytest.mark.asyncio
-    async def test_s3_key_hook_get_file_metadata_async(self):
+    @pytest.mark.parametrize(
+        "requester_pays",
+        [False, True],
+    )
+    async def test_s3_key_hook_get_file_metadata_async_when_requester_pays_is(self, requester_pays):
         """
         Test check_wildcard_key for a valid response
         :return:
@@ -491,7 +581,7 @@ class TestAwsS3Hook:
         mock_paginate.__aiter__.return_value = test_resp_iter
         mock_paginator.paginate.return_value = mock_paginate
 
-        s3_hook_async = S3Hook(client_type="S3")
+        s3_hook_async = S3Hook(client_type="S3", requester_pays=requester_pays)
         mock_client = AsyncMock()
         mock_client.get_paginator = mock.Mock(return_value=mock_paginator)
         keys = [x async for x in s3_hook_async.get_file_metadata_async(mock_client, "test_bucket", "test*")]
@@ -500,6 +590,15 @@ class TestAwsS3Hook:
             {"Key": "test_key", "ETag": "etag1", "LastModified": datetime(2020, 8, 14, 17, 19, 34)},
             {"Key": "test_key2", "ETag": "etag2", "LastModified": datetime(2020, 8, 14, 17, 19, 34)},
         ]
+        extra_params = {}
+        if requester_pays:
+            extra_params["RequestPayer"] = "requester"
+        mock_paginator.paginate.assert_called_with(
+            Bucket="test_bucket",
+            Delimiter="",
+            Prefix="test",
+            **extra_params,
+        )
 
     @pytest.mark.asyncio
     async def test_s3_key_hook_get_head_object_with_error_async(self):
@@ -558,6 +657,20 @@ class TestAwsS3Hook:
             await s3_hook_async.get_head_object_async(mock_client, "s3://test_bucket/file", "test_bucket")
         assert isinstance(err.value, ClientError)
 
+    @pytest.mark.asyncio
+    async def test_get_head_object_async_when_requester_pays(self, s3_bucket):
+        s3_hook_async = S3Hook(client_type="S3", resource_type="S3", requester_pays=True)
+        mock_client = AsyncMock()
+        mock_client.head_object.return_value = None
+
+        await s3_hook_async.get_head_object_async(mock_client, "s3://test_bucket/file", "test_bucket")
+
+        mock_client.head_object.assert_called_with(
+            Key="s3://test_bucket/file",
+            Bucket="test_bucket",
+            RequestPayer="requester",
+        )
+
     @pytest.mark.asyncio
     async def test_s3_key_hook_get_files_without_wildcard_async(self):
         """
@@ -577,11 +690,17 @@ class TestAwsS3Hook:
         mock_paginate.__aiter__.return_value = test_resp_iter
         mock_paginator.paginate.return_value = mock_paginate
 
-        s3_hook_async = S3Hook(client_type="S3", resource_type="S3")
+        s3_hook_async = S3Hook(client_type="S3", resource_type="S3", requester_pays=True)
         mock_client = AsyncMock()
         mock_client.get_paginator = mock.Mock(return_value=mock_paginator)
         response = await s3_hook_async.get_files_async(mock_client, "test_bucket", "test.txt", False)
         assert response == []
+        mock_paginator.paginate.assert_called_with(
+            Bucket="test_bucket",
+            Delimiter="/",
+            Prefix="t",
+            RequestPayer="requester",
+        )
 
     @pytest.mark.asyncio
     async def test_s3_key_hook_get_files_with_wildcard_async(self):
@@ -607,6 +726,11 @@ class TestAwsS3Hook:
         mock_client.get_paginator = mock.Mock(return_value=mock_paginator)
         response = await s3_hook_async.get_files_async(mock_client, "test_bucket", "test.txt", True)
         assert response == []
+        mock_paginator.paginate.assert_called_with(
+            Bucket="test_bucket",
+            Delimiter="/",
+            Prefix="t",
+        )
 
     @pytest.mark.asyncio
     async def test_s3_key_hook_list_keys_async(self):
@@ -635,12 +759,15 @@ class TestAwsS3Hook:
 
     @pytest.mark.asyncio
     @pytest.mark.parametrize(
-        "test_first_prefix, test_second_prefix",
+        "test_first_prefix, test_second_prefix, requester_pays",
         [
-            ("async-prefix1/", "async-prefix2/"),
+            ("async-prefix1/", "async-prefix2/", False),
+            ("async-prefix1/", "async-prefix2/", True),
         ],
     )
-    async def test_s3_prefix_sensor_hook_list_prefixes_async(self, test_first_prefix, test_second_prefix):
+    async def test_s3_prefix_sensor_hook_list_prefixes_async(
+        self, test_first_prefix, test_second_prefix, requester_pays
+    ):
         """
         Test list_prefixes whether it returns a valid response
         """
@@ -650,13 +777,26 @@ class TestAwsS3Hook:
         mock_paginate.__aiter__.return_value = test_resp_iter
         mock_paginator.paginate.return_value = mock_paginate
 
-        s3_hook_async = S3Hook(client_type="S3", resource_type="S3")
+        s3_hook_async = S3Hook(client_type="S3", resource_type="S3", requester_pays=requester_pays)
         mock_client = AsyncMock()
         mock_client.get_paginator = mock.Mock(return_value=mock_paginator)
 
         actual_output = await s3_hook_async.list_prefixes_async(mock_client, "test_bucket", "test")
         expected_output = [test_first_prefix, test_second_prefix]
         assert expected_output == actual_output
+        extra_params = {}
+        if requester_pays:
+            extra_params["RequestPayer"] = "requester"
+        mock_paginator.paginate.assert_called_with(
+            Bucket="test_bucket",
+            Delimiter="",
+            PaginationConfig={
+                "MaxItems": None,
+                "PageSize": None,
+            },
+            Prefix="test",
+            **extra_params,
+        )
 
     @pytest.mark.asyncio
     @pytest.mark.parametrize(
@@ -889,7 +1029,7 @@ class TestAwsS3Hook:
         """
         mock_list_keys.return_value = []
 
-        s3_hook_async = S3Hook(client_type="S3", resource_type="S3")
+        s3_hook_async = S3Hook(client_type="S3", resource_type="S3", requester_pays=True)
         mock_client = AsyncMock()
 
         response = await s3_hook_async.is_keys_unchanged_async(
@@ -1011,7 +1151,7 @@ class TestAwsS3Hook:
         assert response["Grants"][0]["Permission"] == "FULL_CONTROL"
 
     def test_load_file_gzip(self, s3_bucket, tmp_path):
-        hook = S3Hook()
+        hook = S3Hook(requester_pays=True)
         path = tmp_path / "testfile"
         path.write_text("Content")
         hook.load_file(path, "my_key", s3_bucket, gzip=True)
@@ -1038,7 +1178,7 @@ class TestAwsS3Hook:
         assert response["Grants"][0]["Permission"] == "FULL_CONTROL"
 
     def test_copy_object_acl(self, s3_bucket, tmp_path):
-        hook = S3Hook()
+        hook = S3Hook(requester_pays=True)
         path = tmp_path / "testfile"
         path.write_text("Content")
         hook.load_file_obj(path.open("rb"), "my_key", s3_bucket)
@@ -1087,12 +1227,12 @@ class TestAwsS3Hook:
 
     @mock_aws
     def test_copy_object_ol_instrumentation(self, s3_bucket, hook_lineage_collector):
-        mock_hook = S3Hook()
+        mock_hook = S3Hook(requester_pays=True)
 
         with mock.patch.object(
             S3Hook,
             "get_conn",
-        ):
+        ) as get_conn:
             mock_hook.copy_object("my_key", "my_key3", s3_bucket, s3_bucket)
             assert len(hook_lineage_collector.collected_assets.inputs) == 1
             assert hook_lineage_collector.collected_assets.inputs[0].asset == Asset(
@@ -1103,6 +1243,17 @@ class TestAwsS3Hook:
             assert hook_lineage_collector.collected_assets.outputs[0].asset == Asset(
                 uri=f"s3://{s3_bucket}/my_key3"
             )
+            get_conn.return_value.copy_object.assert_called_with(
+                ACL="private",
+                Bucket="airflow-test-s3-bucket",
+                CopySource={
+                    "Bucket": "airflow-test-s3-bucket",
+                    "Key": "my_key",
+                    "VersionId": None,
+                },
+                Key="my_key3",
+                RequestPayer="requester",
+            )
 
     @mock_aws
     def test_delete_bucket_if_bucket_exist(self, s3_bucket):
@@ -1151,7 +1302,7 @@ class TestAwsS3Hook:
     def test_delete_objects_key_does_not_exist(self, s3_bucket):
         # The behaviour of delete changed in recent version of s3 mock libraries.
         # It will succeed idempotently
-        hook = S3Hook()
+        hook = S3Hook(requester_pays=True)
         hook.delete_objects(bucket=s3_bucket, keys=["key-1"])
 
     def test_delete_objects_one_key(self, mocked_s3_res, s3_bucket):
@@ -1204,7 +1355,7 @@ class TestAwsS3Hook:
     def test_download_file(self, mock_temp_file, tmp_path):
         path = tmp_path / "airflow_tmp_test_s3_hook"
         mock_temp_file.return_value = path
-        s3_hook = S3Hook(aws_conn_id="s3_test")
+        s3_hook = S3Hook(aws_conn_id="s3_test", requester_pays=True)
         s3_hook.check_for_key = Mock(return_value=True)
         s3_obj = Mock()
         s3_obj.download_fileobj = Mock(return_value=None)
@@ -1218,7 +1369,7 @@ class TestAwsS3Hook:
         s3_obj.download_fileobj.assert_called_once_with(
             path,
             Config=s3_hook.transfer_config,
-            ExtraArgs=s3_hook.extra_args,
+            ExtraArgs={"RequestPayer": "requester"},
         )
 
         assert path.name == output_file
